#
# spec file for package perl-RPC-XML
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name RPC-XML
Name:           perl-RPC-XML
Version:        0.82
Release:        1.14
Summary:        Set of classes for core data, message and XML handling
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJRAY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         RPC-XML-0.77-fixtest.dif
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.56
BuildRequires:  perl(HTTP::Daemon) >= 6.12
BuildRequires:  perl(HTTP::Message) >= 6.26
BuildRequires:  perl(IO::Socket::IP)
BuildRequires:  perl(LWP) >= 6.51
BuildRequires:  perl(Module::Load) >= 0.36
BuildRequires:  perl(Scalar::Util) >= 1.55
BuildRequires:  perl(Test::More) >= 1.302183
BuildRequires:  perl(XML::Parser) >= 2.46
Requires:       perl(HTTP::Daemon) >= 6.12
Requires:       perl(HTTP::Message) >= 6.26
Requires:       perl(LWP) >= 6.51
Requires:       perl(Module::Load) >= 0.36
Requires:       perl(Scalar::Util) >= 1.55
Requires:       perl(XML::Parser) >= 2.46
Recommends:     perl(DateTime) >= 1.54
Recommends:     perl(DateTime::Format::ISO8601) >= 0.15
Recommends:     perl(XML::LibXML) >= 2.0206
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  perl(HTTP::Daemon)
# MANUAL END

%description
The *RPC::XML* package is an implementation of the *XML-RPC* standard. The
package as a whole provides classes for data, for clients, for servers and
for parsers (based on the XML::Parser and XML::LibXML packages from CPAN).

This module provides a set of classes for creating values to pass to the
constructors for requests and responses. These are lightweight objects,
most of which are implemented as blessed scalar references so as to
associate specific type information with the value. Classes are also
provided for requests, responses and faults (errors).

This module does not actually provide any transport implementation or
server basis. For these, see RPC::XML::Client and RPC::XML::Server,
respectively.

%prep
%autosetup  -n %{cpan_name}-%{version} -p1
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog ChangeLog.xml README README.apache2

%changelog
* Thu Apr  8 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.82
  see /usr/share/doc/packages/perl-RPC-XML/ChangeLog
  0.82	Wednesday January  6, 2021, 09:59:00 AM -0800
  * Makefile.PL
  * lib/RPC/XML/Server.pm
  Bump version numbers.
  * Makefile.PL
  * lib/RPC/XML/Server.pm
  * t/40_server.t
  * t/40_server_xmllibxml.t
  * t/41_server_hang.t
  * t/60_net_server.t
  * t/util.pl
  RT #120472: Applied patch from Petr Písař for fixes to IPv6
  support. Full detail in the message for this commit in the git
  repository.
  0.81	Tuesday January  5, 2021, 06:33:00 PM -0800
  * MANIFEST
  * perlcritic.rc (added)
  Add a perlcritic.rc file for testers who run author tests.
  * t/40_server.t
  * t/40_server_xmllibxml.t
  Remove redundant testing and general clean-up. Removed tests of
  url() that were just re-testing HTTP::Daemon::url().
  * lib/RPC/XML/Client.pm
  Parameterize the request-as-string debug feature.
  * lib/RPC/XML/Client.pm
  Merge pull request #13 from
  enrico-sorcinelli/add-request-string. Added xmlrpc request
  string as object property. (Enrico Sorcinelli)
* Thu Mar 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add perl(HTTP::Daemon) BuildRequires: so far, this was pulled in
  by perl-libwww-perl. The RPC-XML library itself can work with or
  without HTTP::Daemon, but the test suite has an explicit test for
  it.
* Thu Aug 22 2019 Tina Mueller <tina.mueller@suse.com>
- Remove patches not needed anymore:
  * RPC-XML-0.60-rev127.dif
  * RPC-XML-0.76-extern_ent.dif
  * RPC-XML-0.78-reproducible.diff
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.80
  see /usr/share/doc/packages/perl-RPC-XML/ChangeLog
  0.80	Sunday May  8, 2016, 12:45:00 PM -0700
  * etc/make_method
  Make the build reproducible by dropping timestamps in
  make_method output. (Niko Tyni)
  * t/40_server.t
  * t/40_server_xmllibxml.t
  * t/50_client.t
  Fixes for test problems with Strawberry Perl.
  * lib/RPC/XML/Client.pm
  Fix leak caused by failing to free Expat parser. We don't want
  to return from the method until the parser's been freed. We
  therefore need to call $parser->release() before the return
  statements caused by request failures. (Tom Grimwood-Taylor)
  * lib/RPC/XML/Server.pm
  One socket-opt change, one typo corrected.
  * lib/RPC/XML.pm
  Applied patch for numeric regexes and critic cleanup. Addresses
  GitHub pull request #10 and RT #111636.
  * t/60_net_server.t
  RT #99578: Work-around fix for Net::Server+IO::Socket::IP. If a
  system's IPv6 declaration of localhost was before the IPv4
  declaration in the hosts file, this test would fail.
* Tue Mar  8 2016 coolo@suse.com
- update to 0.79
    Test clean-up/fixes to address CPAN test failures. Should
    address problems with having IO::Socket::IP acting in place of
    IO::Socket::INET and also address some issues with a dynloader
    bug being triggered by t/70_compression_detect.t.
- possibly obsoleting RPC-XML-0.60-rev127.dif
* Tue Mar  8 2016 coolo@suse.com
- add RPC-XML-0.78-reproducible.diff to remove date from build result
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.78
  see /usr/share/doc/packages/perl-RPC-XML/ChangeLog
  0.78	Thursday February  6, 2014, 08:00:00 PM -0800
  * lib/RPC/XML.pm
  A patch to loop detection in smart_encode from Dag-Erling
  Smørgrav. Some other minor bits.
  * lib/RPC/XML/Procedure.pm
  RT #83108: Fixed a spelling error. Some other fixes, too.
  * lib/RPC/XML.pm
  RT #86187: Force key-ordering in struct as_string and
  serialize. Was getting some intermittent bug reports of
  failures in t/15_serialize.t that amounted to the keys in a
  fault struct not being in consistent order.
  * lib/RPC/XML.pm
  * t/15_serialize.t
  Undo the previous change and fix the test. The previous change
  didn't feel right, so this rolls it back and fixes the problem
  at the level of the test, instead.
  * Makefile.PL
  * lib/RPC/XML.pm
  * lib/RPC/XML/Client.pm
  * lib/RPC/XML/Server.pm
  Replace direct evals for loading optional modules with
  Module::Load. Required adding this to Makefile.PL because
  Module::Load is not core in 5.8.8. Also did some slight doc
  tweaking.
  * lib/RPC/XML.pm
  * lib/RPC/XML/Client.pm
  Merge pull request #5 from alexrj/utf8-encode. Use
  utf8::encode() instead of utf8::downgrade().
  * lib/RPC/XML.pm
  * lib/RPC/XML/Client.pm
  * lib/RPC/XML/Server.pm
  Finish the uft8 encode vs. downgrade change from the previous
  commit. Changed in places that were overlooked, and adjusted
  the version number in all three modules.
  * lib/RPC/XML.pm
  * lib/RPC/XML/Parser/XMLLibXML.pm
  Merge pull request #6 from dctabuyz/master. Added 'no_blanks'
  libxml option to skip blank XML::LibXML::Text nodes.
  * lib/RPC/XML/Server.pm
  Merge pull request #7 from kvar/master. Initialize $do_compress
  in RPC::XML::Server between requests.
  * lib/RPC/XML.pm
  * lib/RPC/XML/Parser/XMLLibXML.pm
  * lib/RPC/XML/Server.pm
  Bump version numbers on modules changed in github pulls.
* Mon Jul  1 2013 coolo@suse.com
- add RPC-XML-0.77-fixtest.dif to make sure the serialization is
  reproducible even with hash randomization in perl 5.18 (RT#86187)
* Sun May  5 2013 mc@suse.com
- update to version 0.77
  * Make RPC::XML::Server work with Net::Server again,
    after the API changes of Net::Server 2.x.
  * Correct handling of dateTime parameters
  * Add port to Host header in client requests.
  * Fix spelling error in man page
  * improve tests
- remove patches which are unused since a long time
  * RPC-XML-0.53-ext-daemon-and-header-cb.dif
  * RPC-XML-0.60-fix-utf8.dif
* Mon Jun  4 2012 mls@suse.de
- predeclare extern_ent so that it works with perl-5.16.0
* Fri Nov 18 2011 coolo@suse.com
- update to 0.76, see Changes
* Tue Mar 22 2011 coolo@novell.com
- update to 0.74
  * tons and tons of fixes and new functions since 0.67, see ChangeLog
- take out patches of unclear use, to be removed on next update
- regenerate with cpanspec
* Fri Dec 10 2010 coolo@novell.com
- use perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Nov 28 2010 coolo@novell.com
- remove .packlist file
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jul 27 2009 mc@novell.com
- version 0.67
  * a lot of bugfixes and changed tests
* Mon Aug 18 2008 ro@suse.de
- hack to build also in buildservice where 127.0.0.1 can
  resolve to the hostname instead of localhost
* Mon Apr 14 2008 mc@suse.de
- version 0.60
  * fix problem caused by having colons in temp-file names.
  * fix for SSL
  * Fixed the bug in RPC::XML::Server::process_request() could lead to an
    infinite loop if the client shuts down the socket before the full
    request is sent.
  * RPC::XML::smart_encode actually die with an error when a
    reference-type is passed in that cannot be converted.
  * performance improvement
  * fix the XML serialization of double values
* Fri Jul 14 2006 mc@suse.de
- version 0.59
- Fixes to POD documentation
- lib/Apache/RPC/Server.pm:
  Fixed the logic around the setting of $no_def in new(); it was
  handling the no_default method-argument backwards
- fixed some testcases
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Sun Jul 31 2005 cthiel@suse.de
- update to version 0.58
* Fri Apr  1 2005 mc@suse.de
- update to version 0.57
- remove RPC-XML-0.53-http-compress-fix.dif ;
  not needed anymore
* Mon Aug  9 2004 mc@suse.de
- update to version 0.54
* Wed Dec  3 2003 mc@suse.de
- fix http compression (RPC-XML-0.53-http-compress-fix.dif)
* Tue Dec  2 2003 mc@suse.de
- initial version 0.53
